Class: JSON::Ext::ParserConfig
Instance Method Summary collapse
-
#parse(source) ⇒ Object
Parses the current JSON text source and returns the complete data structure as a result.
Instance Method Details
#parse(source) ⇒ Object
Parses the current JSON text source and returns the complete data structure as a result. It raises JSON::ParserError if fail to parse.
2184 2185 2186 2187 2188 |
# File 'ext/json/ext/parser/parser.c', line 2184
static VALUE cParserConfig_parse(VALUE self, VALUE Vsource)
{
GET_PARSER_CONFIG;
return cParser_parse(config, Vsource);
}
|