Class: Time
Class Method Summary collapse
-
.json_create(object) ⇒ Object
See #as_json.
Instance Method Summary collapse
-
#as_json ⇒ Object
Methods
Time#as_jsonandTime.json_createmay be used to serialize and deserialize a Time object; see Marshal. -
#to_json(*args) ⇒ Object
Returns a JSON string representing
self:.
Class Method Details
Instance Method Details
#as_json ⇒ Object
Methods Time#as_json and Time.json_create may be used to serialize and deserialize a Time object; see Marshal.
Method Time#as_json serializes self, returning a 2-element hash representing self:
require 'json/add/time'
x = Time.now.as_json
# => {"json_class"=>"Time", "s"=>1700931656, "n"=>472846644}
Method JSON.create deserializes such a hash, returning a Time object:
Time.json_create(x)
# => 2023-11-25 11:00:56.472846644 -0600
32 33 34 35 36 37 38 |
# File 'lib/json/add/time.rb', line 32 def as_json(*) { JSON.create_id => self.class.name, 's' => tv_sec, 'n' => tv_nsec, } end |