Module: JSON::TruffleRuby::Generator::GeneratorMethods::Hash
- Defined in:
- lib/json/truffle_ruby/generator.rb
Instance Method Summary collapse
-
#to_json(state = nil) ⇒ Object
Returns a JSON string containing a JSON object, that is unparsed from this Hash instance.
Instance Method Details
#to_json(state = nil) ⇒ Object
Returns a JSON string containing a JSON object, that is unparsed from this Hash instance. state is a JSON::State object, that can also be used to configure the produced JSON string output further. depth is used to find out nesting depth, to indent accordingly.
542 543 544 545 546 547 548 549 |
# File 'lib/json/truffle_ruby/generator.rb', line 542 def to_json(state = nil, *) state = State.from_state(state) depth = state.depth state.check_max_nesting json_transform(state) ensure state.depth = depth end |